package com.ruoyi.oa.mapper;

import java.util.List;
import com.ruoyi.oa.domain.CmcResource;

/**
 * 学习资料Mapper接口
 * 
 * @author cmc
 * @date 2025-03-05
 */
public interface CmcResourceMapper 
{
    /**
     * 查询学习资料
     * 
     * @param resourceId 学习资料主键
     * @return 学习资料
     */
    public CmcResource selectCmcResourceByResourceId(Integer resourceId);

    /**
     * 查询学习资料
     *
     * @param cmcResource 学习资料
     * @return 学习资料
     */
    public List<CmcResource> selectCmcResourceListBelow(CmcResource cmcResource);

    /**
     * 查询学习资料列表
     * 
     * @param cmcResource 学习资料
     * @return 学习资料集合
     */
    public List<CmcResource> selectCmcResourceList(CmcResource cmcResource);

    /**
     * 新增学习资料
     * 
     * @param cmcResource 学习资料
     * @return 结果
     */
    public int insertCmcResource(CmcResource cmcResource);

    /**
     * 修改学习资料
     * 
     * @param cmcResource 学习资料
     * @return 结果
     */
    public int updateCmcResource(CmcResource cmcResource);

    /**
     * 删除学习资料
     * 
     * @param resourceId 学习资料主键
     * @return 结果
     */
    public int deleteCmcResourceByResourceId(Integer resourceId);

    /**
     * 批量删除学习资料
     * 
     * @param resourceIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCmcResourceByResourceIds(Integer[] resourceIds);
}
